@@ -34,11 +34,11 @@
 #include <vector>
 #include <memory>
 #include "CacheMemory.h"
-#include "../include/ReaderBase.h"
-#include "../include/Frame.h"
-#include "../include/Fraction.h"
-#include "../include/Exceptions.h"
-#include "../include/KeyFrame.h"
+#include "ReaderBase.h"
+#include "Frame.h"
+#include "Fraction.h"
+#include "Exceptions.h"
+#include "KeyFrame.h"
 
 
 // Include FFmpeg headers and macros
@@ -146,8 +146,7 @@ namespace openshot
 		ReaderBase *reader;		// The source video reader
 		CacheMemory final_cache; 		// Cache of actual Frame objects
 		bool is_dirty; 			// When this is true, the next call to GetFrame will re-init the mapping
-		AVAudioResampleContext *avr;	// Audio resampling context object
-		int64_t timeline_frame_offset;	// Timeline frame offset
+		SWRCONTEXT *avr;	// Audio resampling context object
 
 		// Internal methods used by init
 		void AddField(int64_t frame);
@@ -176,9 +175,6 @@ namespace openshot
 		/// Change frame rate or audio mapping details
 		void ChangeMapping(Fraction target_fps, PulldownType pulldown,  int target_sample_rate, int target_channels, ChannelLayout target_channel_layout);
 
-		// Set offset relative to parent timeline
-		void SetTimelineFrameOffset(int64_t offset);
-
 		/// Close the openshot::FrameMapper and internal reader
 		void Close();
 
